/*--------------------------------------------------------------------*/
/*                        J P _ F O R M T A B                         */
/*                                                                    */
/*       Programmkern fr die Erstellung von Formfaktortabellen       */
/*                                                                    */
/* ADD 27 Nov 2015:  Englische Texte; Argument SPRACHE                */
/* FIX 04 Nov 2016:  Text SUBOUTINE -> REQUIRES in oOREXX 5.0.0       */
/*--------------------------------------------------------------------*/
parse source . aufruf .
if aufruf \= 'SUBROUTINE' & aufruf \= 'REQUIRES' then do /*FIX 04Nov16*/ 
     say 'Programmkern V1.2 fr Formfaktortabelle -- (c) Jochem Peelen'
     exit 0
     end
/*--------------------------------------------------------------------*/
/*                                                                    */
/* Beim Aufruf von JP_FORMF werden folgende Argumente bergeben:      */
/*                                                                    */
/* FLAG       XV oder CW  (Distanz-Geschwindigkeit                    */
/* VDATEN.    bei Flag XV  jedes Element:  distanz v-anfang v-ende    */
/*                         zugleich Rckgabe cw-Werte an den Aufrufer */
/*            bei Flag CW                 machzahl cw-Wert            */
/*                         keine Rckgabe von Daten                   */
/* ZEILE.     Array zur Rckgabe der Ergebniszeilen an den Aufrufer   */
/* DURCHM     Geschossdurchmesser [mm]                                */
/* MASSE      Geschossmasse [g]                                       */
/* LUFTD      Luftdichte [kg/m**3]                                    */
/* SCHALL     Schallgeschwindigkeit [m/s]                             */
/* FEETFLAG   leer oder J                                             */
/* DUPUFLAG   leer oder DUPALL                                        */
/* SPRACHE    leer oder EN                                            */
/*                                                                    */
/*--------------------------------------------------------------------*/
::ROUTINE JP_FORMF      PUBLIC
numeric digits 15                 /* hhere Genauigkeit als 9 Ziffern */
/*--------------------------------------------------------------------*/
/* bergebene Argumente lesen                                         */
/*--------------------------------------------------------------------*/
use arg flag , vdaten. , zeile. , durchm , masse , luftd , schall , feetflag , dupuflag , sprache
select
when flag = 'XV' then nop
when flag = 'CW' then nop
otherwise
     say 'Ungltiger Aufruf von JP_FORMF'
     return 24
     end
if feetflag = 'FEETFLAG' then feetflag = ''     /* Flag nicht gesetzt */
if dupuflag = 'DUPUFLAG' then dupuflag = ''
/*--------------------------------------------------------------------*/
/* Standardliste der Luftwidestandsmodelle erzeugen:                  */
/* LWNAM.    Array mit den Namen der Luftwiderstandmodelle            */
/* BER.      Array mit dem Gltigkeitsbereich (Mach) jedes Modells    */
/* Element 0 enthlt jeweils die Anzahl der Array-Elemente            */
/* LWVERS    Versionstext von JP_LWMod.rex                            */
/*--------------------------------------------------------------------*/
lwvers = JP_LWLISTE(lwnam.,ber.)
lwz = lwnam.0        /* Anzahl der Luftwiderstandsmodelle in JP_LWMod */
/*--------------------------------------------------------------------*/
/* Fr DUPUIS-Modell Liste der Kennzahlen (j-Werte) erzeugen; ohne    */
/* die in der Standardliste schon vorhandenen: 0.040, 0.140 und 0.240 */
/*--------------------------------------------------------------------*/
dplist = '0.000 0.002 0.004 0.006 0.008 0.010 0.012 0.014 0.016 0.018' ,
         '0.020 0.022 0.024 0.026 0.028 0.030 0.032 0.034 0.036 0.038' ,
         '      0.042 0.044 0.046 0.048 0.050 0.052 0.054 0.056 0.058' ,
         '0.060 0.062 0.064 0.066 0.068 0.070 0.072 0.074 0.076 0.078' ,
         '0.080 0.082 0.084 0.086 0.088 0.090 0.092 0.094 0.096 0.098' ,
         '0.100 0.105 0.110 0.115 0.120 0.125 0.130       0.150 0.160' ,
         '0.170 0.180 0.190 0.200 0.210 0.220 0.230       0.250 0.260' ,
         '0.280 0.300'
dpz = words(dplist)          /* Anzahl der Kennzahlen in der Liste    */
do i=1 to  dpz
     jot.i = word(dplist,i)  /* DPLIST in Kennzahlen zerlegen         */
     end i
/*--------------------------------------------------------------------*/
/* Akkumulatoren zur spteren Berechnung von Mittelwerten und Stan-   */
/* dardabweichung der Formfaktoren fr die einzelnen LW-Modelle.      */
/*--------------------------------------------------------------------*/
do i=1 to lwz
     ffsumm.i  = 0           /* Summe der Einzelwerte                 */
     ffsummq.i = 0           /* Summe der Quadrate                    */
     ffanz.i   = 0           /* Anzahl Cw-Werte im Gltigkeitsbereich */
     end
do i=1 to dpz                /* Akkumulatoren fr DUPUIS Formwerte    */
     dpsumm.i  = 0           /* Summe der Einzelwerte                 */
     dpsummq.i = 0           /* Summe der Quadrate                    */
     dpanz.i   = 0           /* Anzahl Cw-Werte im Gltigkeitsbereich */
     end
/*--------------------------------------------------------------------*/
/* Falls Flag CW gesetzt ist:                                         */
/* Lesen der vorgegebenen Mach / Cw-Tabelle                           */
/* Mit dem Buchstaben  i  beginnende Zeilen werden bersprungen.      */
/*--------------------------------------------------------------------*/
zhl = 0                                           /* Anzahl der Werte */
if flag = 'CW' then do i=1 for vdaten.0
     if left(vdaten.i,1) = 'i' then iterate i     /* Wert ignorieren  */
     zhl = zhl + 1
     parse var vdaten.i mmitt.zhl cweff.zhl .
     end
/*--------------------------------------------------------------------*/
/* Dies ist keine CW-Auswertung: Geschoss- und Atmosphrendaten lesen */
/* und aus Geschwindigkeitsdaten den effektiven CW berechnen.         */
/*--------------------------------------------------------------------*/
else do
     masse  = masse  / 1000        /* Umrechnung in kg                */
     radius = durchm / 2000        /* Durchmesser (mm) --> Radius (m) */
     qb     = masse  / ( RxCalcPi() * radius**2 ) /* Querschnittsbel. */
     /*---------------------------------------------------------------*/
     /* Schleife: Distanz- / Geschwindigkeitspaare auswerten          */
     /* Mit dem Buchstaben  i  beginnende Zeilen werden bersprungen. */
     /*---------------------------------------------------------------*/
     zhl = 0
     do i=1 for vdaten.0
          if left(vdaten.i,1) = 'i' then iterate i /*Zeile ignorieren */
          parse var vdaten.i distanz vanf vend .
          /*----------------------------------------------------------*/
          /* Mittlere Geschwindigkeit und Cw berechnen.               */
          /*----------------------------------------------------------*/
          if feetflag = '' then nop          /* keine Umrechnung      */
          else do
               vanf = vanf * 0.3048          /* ft/s umrechnen in m/s */
               vend = vend * 0.3048
               end
          k = RxCalcLog(vanf/vend) / distanz /* K aus Geschwindigkeit */
          zhl = zhl + 1                      /* Zhler Wertepaare     */
          cweff.zhl = k * 2 * qb / luftd     /* effektiver Cw aus K   */
          /*----------------------------------------------------------*/
          /* mittlere Geschwindigkeit, fr die cweff gilt             */
          /*----------------------------------------------------------*/
          vmitt.zhl = (vanf + vend) / 2
          mmitt.zhl = vmitt.zhl / schall     /* dto. als Machzahl     */
          /*----------------------------------------------------------*/
          /* Errechnete Werte fr Rckgabe an Eingabedaten anhngen   */
          /*----------------------------------------------------------*/
          vdaten.i = left(vdaten.i,33)'  'format(vmitt.zhl,4,1)'  'format(mmitt.zhl,2,4)'   'format(cweff.zhl,2,4)
          end i
     end
/*--------------------------------------------------------------------*/
/*                                                                    */
/* Die Ausgangsdaten sind nun vorhanden: Formfaktoren berechnen       */
/*                                                                    */
/*--------------------------------------------------------------------*/
machmin = 99
machmax = 0
do i=1 for zhl                       /* Durchlauf fr jeden CW-Wert   */
     mach  = mmitt.i
     if mach < machmin then machmin = mach
     if mach > machmax then machmax = mach
     do j=1 for lwz                  /* Durchlauf fr alle LW-Gesetze */
          call (lwnam.j) mach        /* Setzt Variable CW             */
          cw = result
          if cw = 0 then iterate j   /* Mach auerhalb Gltigkeit     */
          ff    = cweff.i / cw       /* Formfaktor = effektiv / Gesetz*/
          ffsumm.j  = ffsumm.j + ff
          ffsummq.j = ffsummq.j + ff**2
          ffanz.j   = ffanz.j + 1
          end j
     /*---------------------------------------------------------------*/
     /* ADD 16.06.13: Dasselbe fr DUPUIS Liste der j-Werte           */
     /*---------------------------------------------------------------*/
     do j=1 for dpz                  /* Durchlauf fr alle j-Werte    */
          cw = dupuis(jot.j,mach)
          if cw = 0 then iterate j   /* Mach auerhalb Gltigkeit     */
          ff    = cweff.i / cw       /* Formfaktor = effektiv / Gesetz*/
          dpsumm.j  = dpsumm.j + ff
          dpsummq.j = dpsummq.j + ff**2
          dpanz.j   = dpanz.j + 1
          end j
     end i
/*--------------------------------------------------------------------*/
/* Mittelwerte und Standardabweichung berechnen; Ausgabezeile forma-  */
/* tieren.                                                            */
/*--------------------------------------------------------------------*/
do i=1 for lwz
     if ffanz.i = 0 then mitt = 0
     else mitt = ffsumm.i / ffanz.i
     if ffanz.i < 2 then stda = 0
     else do
          work = ffsummq.i - ( ffsumm.i * ffsumm.i / ffanz.i )
          work = work / ( ffanz.i - 1 )
          stda = RxCalcSqrt(work)
          /* Standardabweichung in % des Formfator Mittelwerts        */
          stda = stda / mitt * 100
          end
     zeile.i = '* ' left(lwnam.i,13) format(mitt,2,4) format(stda,5,3) ,
                format(ffanz.i,4)'      'left(ber.i,12)
     end i
/*--------------------------------------------------------------------*/
/* Auch fr DUPUIS Kennzahlen: Mittelwerte und Standardabweichung     */
/*--------------------------------------------------------------------*/
do i=1 for dpz
     if dpanz.i = 0 then mitt = 0
     else mitt = dpsumm.i / dpanz.i
     if dpanz.i < 2 then stda = 0
     else do
          work = dpsummq.i - ( dpsumm.i * dpsumm.i / dpanz.i )
          work = work / ( dpanz.i - 1 )
          stda = RxCalcSqrt(work)
          stda = stda / mitt * 100
          end
     /*---------------------------------------------------------------*/
     /* Wenn DUPUFLAG den Wert DUPALL hat, sollen alle DUPUIS-Varian- */
     /* ten ausgegeben werden. Dazu werden sie einfach an die beste-  */
     /* hende Liste angehngt.                                        */
     /* Anderenfalls kommen sie in eine eigene Liste, um nur den      */
     /* besten Wert selektieren zu knnen.                            */
     /*---------------------------------------------------------------*/
     if dupuflag = 'DUPALL' then do
          lwz = lwz + 1
          zeile.lwz = '* ' left('DUPUIS_'substr(jot.i,3),13) format(mitt,2,4) ,
             format(stda,5,3) format(dpanz.i,4)'      'left('1.0 ... 5.62',12)
          end
     else do
          zdupu.i = '* ' left('DUPUIS_'substr(jot.i,3),13) format(mitt,2,4) ,
             format(stda,5,3) format(dpanz.i,4)'      'left('1.0 ... 5.62',12)
          end
     end i
if dupuflag = 'DUPALL' then nop
else do
     /*---------------------------------------------------------------*/
     /* DUPUIS-Ausgabeliste aufsteigend sortieren nach StdAbw.        */
     /* Das erste Element in ZDUPU. hat dann die kleinste StdAbw. Nur */
     /* dieses Element dem Ergebnis-Array ZEILE. hinzufgen           */
     /*---------------------------------------------------------------*/
     zdupu.0 = dpz
     rc = SysStemSort('zdupu.',,,,,28,34)
     if rc \= 0 then do
          say 'Fehler' rc 'beim DUPUIS-Stemsort'
          return                                   /* Programmabbruch */
          end
     lwz = lwz + 1                   /* Zhler der LW-Modelle erhhen */
     zeile.lwz = zdupu.1             /* Inhalt der 1. Zeile kopieren  */
     end
/*--------------------------------------------------------------------*/
/*                      Ausgabezeilen sortieren                       */
/*--------------------------------------------------------------------*/
/* Die Modelle mit der grten Anzahl Werte im Gltigkeitsbereich kom-*/
/* men zuerst. Deshalb nach Zahl der Messwerte vorsortieren.          */
/*--------------------------------------------------------------------*/
zeile.0 = lwz
rc = SysStemSort('zeile.','D',,,,36,39) /* hchste Messwertanzahl oben*/
if rc \= 0 then do
     say 'Fehler' rc 'beim Stemsort nach Messwertanzahl'
     return                                        /* Programmabbruch */
     end
/*--------------------------------------------------------------------*/
/* Feststellen, bei welchen Elementen die Messwertanzahl wechselt.    */
/* Elementnummern in Liste WECHSELL speichern, damit innerhalb der    */
/* Blocks mit gleicher Messwertzahl sortiert werden kann.             */
/*--------------------------------------------------------------------*/
ele      = 1
wechsell = 1                          /* 1. Element: immer neue Anzahl*/
startanz = substr(zeile.ele,36,4)     /* Messwertanzahl im 1. Element */
do ele=2 to zeile.0                   /* und in Folgeelementen lesen  */
     anz = substr(zeile.ele,36,4)
     if anz = startanz then iterate   /* gleichbleibende ignorieren   */
     wechsell = wechsell ele          /* sonst an Liste anhngen      */
     startanz = anz
     end ele
wwechsell = words(wechsell)  /* Anzahl der Elemente in Liste WECHSELL */
if wwechsell = 1 then do
     /*---------------------------------------------------------------*/
     /* Es kommt nur eine Messwertanzahl vor: ein einziger Sortier-   */
     /* lauf gengt (nach Standardabweichung in Spalten 28-34)        */
     /*---------------------------------------------------------------*/
     rc = SysStemSort('zeile.',,,,,28,34)
     if rc \= 0 then do
          say 'Fehler' rc 'beim Gesamt-Stemsort'
          return                                   /* Programmabbruch */
          end
     end
else do
     /*---------------------------------------------------------------*/
     /* Blockweise die Elemente mit gleicher Messwertanzahl nach der  */
     /* Standardabweichung sortieren.                                 */
     /*---------------------------------------------------------------*/
     do i=1 for wwechsell-1
          startele = word(wechsell,i)
          endele   = word(wechsell,i+1)-1
          if startele = endele then do
               /*-----------------------------------------------------*/
               /* Block besteht nur aus einer Zeile: keine Sortierung */
               /*-----------------------------------------------------*/
               iterate i
               end
          rc = SysStemSort('zeile.',,,startele,endele,28,34)
          if rc \= 0 then do
               say 'Fehler' rc 'bei StemSort' startele'-'endele
               return                              /* Programmabbruch */
               end
          end i
     /*---------------------------------------------------------------*/
     /* Sonderfall des letzten Anzahlwechsels                         */
     /*---------------------------------------------------------------*/
     startele = word(wechsell,wwechsell)
     if startele = zeile.0 then do
          /* Neue Anzahl beginnt in der letzte Zeile: kein Sort mehr  */
          nop
          end
     else do            /* sonst letzten Block bis zum Ende sortieren */
          rc = SysStemSort('zeile.',,,startele,zeile.0,28,34)
          if rc \= 0 then do
               say 'Fehler' rc 'bei StemSort letzter Block'
               return                              /* Programmabbruch */
               end
          end
     end /* blockweise Sortierschritte */
/*--------------------------------------------------------------------*/
/* Platzziffern an die Ergebniszeilen anhngen                        */
/*--------------------------------------------------------------------*/
do i=1 for lwz
     zeile.i = zeile.i '   ' format(i,3,0)
     end i
/*--------------------------------------------------------------------*/
/* Trailerzeilen hinzufgen                                           */
/*--------------------------------------------------------------------*/
if sprache = 'EN' then do
     lwz = lwz + 1
     zeile.lwz = '*----------------------------------------------------------------------*'
     lwz = lwz + 1
     zeile.lwz = '* computed using' lwvers 'on:' date() time()
     lwz = lwz + 1
     zeile.lwz = '*' zhl 'CW values within Mach' format(machmin,1,2)'-'format(machmax,1,2)'  spread:' format(machmax-machmin,1,2)
     zeile.0 = lwz
     end
else do
     lwz = lwz + 1
     zeile.lwz = '*----------------------------------------------------------------------*'
     lwz = lwz + 1
     zeile.lwz = '* mit' lwvers 'gerechnet am:' date() time()
     lwz = lwz + 1
     zeile.lwz = '*' zhl 'CW im Machband' format(machmin,1,2)'-'format(machmax,1,2)'  Breite:' format(machmax-machmin,1,2)
     zeile.0 = lwz
     end
/*--------------------------------------------------------------------*/
/* Mit Rckgabe der Kontrolle an das aufrufende Programm werden dort  */
/* die als 2. und 3. Argument bergebenen Arrays mit den hier erzeug- */
/* ten neuen Inhalten (VDATEN. und ZEILE.) sichtbar.                  */
/* (Bei Bearbeitung einer CW-Tabelle ist VDATEN. unverndert.)        */
/*--------------------------------------------------------------------*/
return 0
/*--------------------------------------------------------------------*/
/*                                                                    */
/*         Leerer Dateikopf fr Distanz-/Gechwindigkeitspaare         */
/*                                                                    */
/*--------------------------------------------------------------------*/
::ROUTINE  JP_EMPTY     PUBLIC
use arg zeile.
zeile.1  = '*++--------------------------------------------------------------------*'
zeile.2  = '*                  F o r m f a k t o r t a b e l l e                   *'
zeile.3  = '*                                                                      *'
zeile.4  = '* Patrone:                                                             *'
zeile.5  = '*                                                                      *'
zeile.6  = '*                                                                      *'
zeile.7  = '*                                                                      *'
zeile.8  = '*----------------------------------------------------------------------*'
zeile.9  = '* Durchmesser  Masse  Luftdichte  Schallgeschwindigkeit                *'
zeile.10 = '*     mm         g      kg/m3       m/s                                *'
zeile.11 = '*----------------------------------------------------------------------*'
zeile.12 = '*  xx.xx      xx.xx    1.225     340.429'
zeile.13 = '*-------------------------------+--------------------------------------*'
zeile.14 = '*     Geschwindigkeitspaare     |         daraus berechnet:            *'
zeile.15 = '*                               |                                      *'
zeile.16 = '* Distanz Anfangs-   End-       |   mittlere          dazu             *'
zeile.17 = '*         geschwindigkeit       |   Geschwindigkeit   Cw               *'
zeile.18 = '*   m     [m/s oder ft/s]       |   m/s     Mach                       *'
zeile.19 = '*!------------------------------+--------------------------------------*'
zeile.20 = '   100    895        806            xxx.x   x.xxxx    x.xxxx'
zeile.21 = '   100    .          .                                      '
zeile.22 = '   100    .          .                                      '
zeile.23 = '*----------------------------------------------------------------------*'
zeile.24 = '*                         A u s w e r t u n g                          *'
zeile.25 = '*                                                                      *'
zeile.26 = '*                 <- Formfaktor  ->  Anzahl im Gueltigkeits-           *'
zeile.27 = '*  LW-Modell      Mittel   %Std-Abw  Werte   bereich [Mach]  Rang      *'
zeile.28 = '*=---------------------------------------------------------------------*'
zeile.0  = 28
return 0
/*--------------------------------------------------------------------*/
/*                                                                    */
/*                       dto. englische Version                       */
/*                                                                    */
/*--------------------------------------------------------------------*/
::ROUTINE  JP_EMPTY2    PUBLIC
use arg zeile.
zeile.1  = '*++--------------------------------------------------------------------*'
zeile.2  = '*                  F o r m   F a c t o r   T a b l e                   *'
zeile.3  = '*                                                                      *'
zeile.4  = '* Cartridge:                                                           *'
zeile.5  = '*                                                                      *'
zeile.6  = '*                                                                      *'
zeile.7  = '*                                                                      *'
zeile.8  = '*----------------------------------------------------------------------*'
zeile.9  = '*  Diameter     Mass  Air Density  Speed of sound                      *'
zeile.10 = '*     mm         g      kg/m3       m/s                                *'
zeile.11 = '*----------------------------------------------------------------------*'
zeile.12 = '*  xx.xx      xx.xx    1.225     340.429'
zeile.13 = '*-------------------------------+--------------------------------------*'
zeile.14 = '*     Range/velocity pairs      |         Computed data:               *'
zeile.15 = '*                               |                                      *'
zeile.16 = '* Range  Initial- Terminal-     |                                      *'
zeile.17 = '*            velocity           |   Mean velocity  Corresponding       *'
zeile.18 = '*   m     [m/s  or  ft/s]       |   m/s     Mach       cw              *'
zeile.19 = '*!------------------------------+--------------------------------------*'
zeile.20 = '   100    895        806            xxx.x   x.xxxx    x.xxxx'
zeile.21 = '   100    .          .                                      '
zeile.22 = '   100    .          .                                      '
zeile.23 = '*----------------------------------------------------------------------*'
zeile.24 = '*                           A n a l y s i s                            *'
zeile.25 = '*                                                                      *'
zeile.26 = '*                 <- Form factor ->  Data     Within valid             *'
zeile.27 = '*  Drag model     mean     %Std-Dev  points  range   [Mach]   Rank     *'
zeile.28 = '*=---------------------------------------------------------------------*'
zeile.0  = 28
return 0
/*--------------------------------------------------------------------*/
/*                                                                    */
/*                  Leerer Dateikopf fr  cw-Tabelle                  */
/*                                                                    */
/*--------------------------------------------------------------------*/
::ROUTINE  JP_EMPTYCW   PUBLIC
use arg zeile.
zeile.1  = '*++--------------------------------------------------------------------*'
zeile.2  = '*          F o r m f a k t o r   a u s   c w - T a b e l l e           *'
zeile.3  = '*                                                                      *'
zeile.4  = '* Patrone:                                                             *'
zeile.5  = '*                                                                      *'
zeile.6  = '*                                                                      *'
zeile.7  = '*                                                                      *'
zeile.8  = '*  Mach      cw               (FORMFAK-Makro mit  CW  aufrufen)        *'
zeile.9  = '*%---------------------------------------------------------------------*'
zeile.10 = '   x.xx      x.xxxxx'
zeile.11 = '    .         .     '
zeile.12 = '*----------------------------------------------------------------------*'
zeile.13 = '*                         A u s w e r t u n g                          *'
zeile.14 = '*                                                                      *'
zeile.15 = '*                 <- Formfaktor  ->  Anzahl im Gueltigkeits-           *'
zeile.16 = '*  LW-Modell      Mittel   %Std-Abw  Werte   bereich [Mach]  Rang      *'
zeile.17 = '*=---------------------------------------------------------------------*'
zeile.0  = 17
return 0
/*--------------------------------------------------------------------*/
/*                                                                    */
/*                       dto. englische Version                       */
/*                                                                    */
/*--------------------------------------------------------------------*/
::ROUTINE  JP_EMPTYCW2  PUBLIC
use arg zeile.
zeile.1  = '*++--------------------------------------------------------------------*'
zeile.2  = '*         F o r m   F a c t o r s   f r o m   c w   D a t a            *'
zeile.3  = '*                                                                      *'
zeile.4  = '* Cartridge:                                                           *'
zeile.5  = '*                                                                      *'
zeile.6  = '*                                                                      *'
zeile.7  = '*                                                                      *'
zeile.8  = '*  Mach      cw               (Start FORMFAK using  CW  argument)      *'
zeile.9  = '*%---------------------------------------------------------------------*'
zeile.10 = '   x.xx      x.xxxxx'
zeile.11 = '    .         .     '
zeile.12 = '*----------------------------------------------------------------------*'
zeile.13 = '*                           A n a l y s i s                            *'
zeile.14 = '*                                                                      *'
zeile.15 = '*                 <- Form factor ->  Data   Within validity            *'
zeile.16 = '*  Drag model     mean     %Std-Dev  points  range   [Mach]   Rank     *'
zeile.17 = '*=---------------------------------------------------------------------*'
zeile.0  = 17
return 0
/*--------------------------------------------------------------------*/
/* Liste benutzter Bibliotheken und externer Funktionen               */
/*--------------------------------------------------------------------*/
::REQUIRES 'rxmath' LIBRARY /* DLL mit mathematischen Rexx-Funktionen */
::REQUIRES 'JP_LWMod.rex'   /* eigene Luftwiderstandsmodelle          */
/* sowie:   SysStemSort()      Rexx Utilities                         */
